.. _quickstart-sdk:

==========
Quickstart
==========

To use BioLM AI in a project::

    import biolmai


There are numerous Python classes in the SDK, each of which can help you make
an efficient request to a BioLM model endpoint. In order to make a request
to an API, a class has one or more actionable methods that the model allows,
such as Predict, Generate, Encode, and others. For details see each Class's documentation.

Below are some examples showcasing various functionalities of the SDK.



Example Prediction

Example Encoding

Example Generation
